# ScratchPlus
## Что такое ScratchPlus?
**ScratchPlus** - это библиотека для работы со Scratch Api для Python :snake:.
## Что может наш модуль?
- [✔️] Работать с данными скретча
- [✔️] Писать и читать комментарии 
- [✔️] Работать с облачными проектами на Scratch
- [❌] Регестрироватся на Scratch
- [✔️] Читать форумы и получать данные о постах
- [✔️] Кодирование числовых облачных данных скретча в обычные строки
- [❌] Постить на форумах
## Преимущества перед аналогом (ScratchClient)
- [👍] Возможность автоматический кодировать и декодировать облачные данные  
- [👍] Чтение комментариев профиля путём парсинга
- [👍] Если вы не хотите входить в аккаунт, есть Read-Only режим.
- [👍] Вы можете войти в несколько аккаунтов сразу и выполнять от них действия в асинхронном режиме

## Используймые библеотеки  или API:
- [Requests](github.com/psf/requests) - Библеотека Для удобной работы с протоколом HTTP.
- [ScratchDB](https://scratchdb.lefty.one/) - API Для работы с форумами на Scratch.
- [IsScratcher](https://github.com/hello-smile6/isScratcher) - API Для проверки статуса Скретчера

## Установка
Для установки можно возпользоваться командой
```pip install scratchplus```

## Документация
### Подключение к аккаунту
Для работы с большей части API нужно авторизоваться (см. ниже)
```
from scratchplus import Session
account = Session("username_on_scratch", "password")
```
### Методы Get
После авторизации, мы можем получить объект из APi для далнейшей работы с ним
Здесь будет приведёт список всех Get Заросов 
#### get_user
```
account.get_user("username")
```
Метод возращает объект класса YourUser или AnotherUser 
